@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -1001,4 +1001,15 @@ public:
     virtual HRESULT __stdcall DelFavorites(LPENTRYLIST lpEntryList) = 0;
 };
 
+/* New from Outlook 2010 MAPI Extension */
+class IMAPIGetSession : public IUnknown {
+public:
+    //    virtual ~IMAPIGetSession() = 0;
+
+	virtual HRESULT __stdcall GetMAPISession(LPUNKNOWN *lppSession) = 0;
+};
+
+typedef IMAPIGetSession* LPMAPIGETSESSION;
+
+
 #endif
