@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -79,7 +79,7 @@ private:
 	ULONG				m_ulFlags;
 	ULONG				m_ulDepth;
 	MAPITablePtr		m_ptrTable;
-	mapi_rowset_ptr		m_ptrRows;
+	SRowSetPtr			m_ptrRows;
 	ULONG				m_ulRowIndex;
 	MAPIContainerPtr	m_ptrCurrent;
 };
@@ -138,7 +138,7 @@ private:
 	ULONG				m_ulFlags;
 	SRestrictionPtr		m_ptrRestriction;
 	MAPITablePtr		m_ptrTable;
-	mapi_rowset_ptr		m_ptrRows;
+	SRowSetPtr			m_ptrRows;
 	ULONG				m_ulRowIndex;
 	UnknownPtr			m_ptrCurrent;
 };
