@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -71,15 +71,38 @@ public:
 
 	virtual ~ECRestriction() {}
 
-	HRESULT CreateMAPIRestriction(LPSRestriction *lppRestriction, ULONG ulFlags = 0);
+	/**
+	 * Create an LPSRestiction object that represents the restriction on which CreateMAPIRestriction was called.
+	 * @param[in]	lppRestriction	Pointer to an LPSRestriction pointer, that will be set to the address
+	 * 								of the newly allocated restriction. This memory must be freed with
+	 * 								MAPIFreeBuffer.
+	 * @param[in]	ulFlags			When set to ECRestriction::Cheap, not all data will be copied to the 
+	 * 								new MAPI restriction. This is usefull if the ECRestriction will outlive
+	 * 								the MAPI restriction.
+	 */
+	HRESULT CreateMAPIRestriction(LPSRestriction *lppRestriction, ULONG ulFlags = 0) const;
+	
+	/**
+	 * Apply the restriction on a table.
+	 * @param[in]	lpTable		The table on which to apply the restriction.
+	 */
+	HRESULT RestrictTable(LPMAPITABLE lpTable) const;
+
+	/**
+	 * Use the restriction to perform a FindRow on the passed table.
+	 * @param[in]	lpTable		The table on which to perform the FindRow.
+	 * @param[in]	BkOrigin	The location to start searching from. Directly passed to FindRow.
+	 * @param[in]	ulFlags		Flags controlling search behaviour. Directly passed to FindRow.
+	 */
+	HRESULT FindRowIn(LPMAPITABLE lpTable, BOOKMARK BkOrigin, ULONG ulFlags) const;
 
 	/**
 	 * Populate an SRestriction structure based on the objects state.
 	 * @param[in]		lpBase			Base pointer used for allocating additional memory.
 	 * @param[in,out]	lpRestriction	Pointer to the SRestriction object that is to be populated.
 	 */
-	virtual HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags = 0) = 0;
-
+	virtual HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags = 0) const = 0;
+	
 	/**
 	 * Create a new ECRestriction derived class of the same type of the object on which this
 	 * method is invoked.
@@ -95,8 +118,8 @@ protected:
 	typedef std::list<ResPtr>					ResList;
 
 	ECRestriction() { }
-	HRESULT CopyProp(LPSPropValue lpPropSrc, LPVOID lpBase, ULONG ulFLags, LPSPropValue *lppPropDst);
-	HRESULT CopyPropArray(ULONG cValues, LPSPropValue lpPropSrc, LPVOID lpBase, ULONG ulFLags, LPSPropValue *lppPropDst);
+	HRESULT CopyProp(LPSPropValue lpPropSrc, LPVOID lpBase, ULONG ulFLags, LPSPropValue *lppPropDst) const;
+	HRESULT CopyPropArray(ULONG cValues, LPSPropValue lpPropSrc, LPVOID lpBase, ULONG ulFLags, LPSPropValue *lppPropDst) const;
 
 	static void DummyFree(LPVOID);
 };
@@ -147,7 +170,7 @@ public:
 	: m_lstRestrictions(1, ResPtr(restriction.Clone())) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 	HRESULT append(const ECRestriction &restriction) {
@@ -170,7 +193,7 @@ public:
 	: m_lstRestrictions(1, ResPtr(restriction.Clone())) 
 	{ }
 	
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 	HRESULT append(const ECRestriction &restriction) {
@@ -190,7 +213,7 @@ public:
 	: m_ptrRestriction(ResPtr(restriction.Clone())) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -204,7 +227,7 @@ class ECContentRestriction : public ECRestriction {
 public:
 	ECContentRestriction(ULONG ulFuzzyLevel, ULONG ulPropTag, LPSPropValue lpProp, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -224,7 +247,7 @@ public:
 	, m_ulMask(ulMask) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -237,7 +260,7 @@ class ECPropertyRestriction : public ECRestriction {
 public:
 	ECPropertyRestriction(ULONG relop, ULONG ulPropTag, LPSPropValue lpProp, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -257,7 +280,7 @@ public:
 	, m_ulPropTag2(ulPropTag2)
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -274,7 +297,7 @@ public:
 	, m_cb(cb)
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -289,7 +312,7 @@ public:
 	: m_ulPropTag(ulPropTag) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -303,7 +326,7 @@ public:
 	, m_ptrRestriction(ResPtr(restriction.Clone()))
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -318,7 +341,7 @@ class ECCommentRestriction : public ECRestriction {
 public:
 	ECCommentRestriction(const ECRestriction &restriction, ULONG cValues, LPSPropValue lpProp, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
@@ -338,7 +361,7 @@ class ECRawRestriction : public ECRestriction {
 public:
 	ECRawRestriction(LPSRestriction lpRestriction, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags);
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
 	ECRestriction *Clone() const;
 
 private:
