@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -50,11 +50,26 @@
 #ifndef PLATFORM_H
 #define PLATFORM_H
 
+/* About _FORTIFY_SOURCE a.k.a. _BREAKIFY_SOURCE_IN_INSANE_WAYS
+ *
+ * This has the insane feature that it will assert() when you attempt
+ * to FD_SET(n, &set) with n > 1024, irrespective of your compile-time FD_SETSIZE
+ * Even stranger, this should be easily fixed but nobody is interested apparently.
+ *
+ * Although you could just not use select() anywhere, we depend on some libs that
+ * are doing select(), so we can't just remove them. 
+ *
+ * This will also disable a few other valid buffer-overflow checks, but we'll have
+ * to live with that for now.
+ */
+
+#ifdef _FORTIFY_SOURCE
+#undef _FORTIFY_SOURCE
+#endif
+
 
   // We have to include this now in case select.h is included too soon.
   // Increase our maximum amount of file descriptors to 8192
-  // But only if you don't have a glibc that doesn't check for this compiletime limit
-  #ifndef _FORTIFY_SOURCE
   #if OPENBSD
   #include <sys/types.h>
   #include <sys/select.h>
@@ -63,7 +78,6 @@
   #endif
   #undef __FD_SETSIZE
   #define __FD_SETSIZE 8192
-  #endif
 
   // Log the pthreads locks
   #define DEBUG_PTHREADS 0
@@ -116,6 +130,8 @@ struct tm* gmtime_safe(const time_t* timer, struct tm *result);
  */
 struct timespec GetDeadline(unsigned int ulTimeoutMs);
 
+double timespec2dbl(timespec t);
+
 bool operator ==(FILETIME a, FILETIME b);
 bool operator >(FILETIME a, FILETIME b);
 bool operator <(FILETIME a, FILETIME b);
